@@ -1,6 +1,6 @@
 /*
  * libusb_wrap.c
- * $Id: libusb_wrap.c,v 1.1.1.7 2004/07/24 21:57:24 rousseau Exp $
+ * $Id: libusb_wrap.c,v 1.7 2005/06/17 12:42:46 rousseau Exp $
  * USB access routines using the libusb library
  *
  * Created by Ludovic Rousseau on Sep 27 2002
@@ -59,6 +59,14 @@ typedef struct
 {
 	usb_dev_handle *handle;
 	struct usb_device *dev;
+	int interface;
+
+	/*
+	 * Endpoints
+	 */
+	int bulk_in;
+	int bulk_out;
+
 } _usbDevice;
 
 #if (PCSCLITE_MAX_READERS-16)
@@ -204,6 +212,10 @@ status_t OpenUSB(DWORD lun, LPTSTR device)
 					/* store device information */
 					usbDevice[reader].handle = dev_handle;
 					usbDevice[reader].dev = dev;
+					usbDevice[reader].interface = interface;
+
+					usbDevice[reader].bulk_in = usbDevice[reader].dev->config->interface->altsetting->endpoint[USB_INEP].bEndpointAddress;
+					usbDevice[reader].bulk_out = usbDevice[reader].dev->config->interface->altsetting->endpoint[USB_OUTEP].bEndpointAddress;
 
 					goto end;
 				}
@@ -227,33 +239,37 @@ status_t WriteUSB(DWORD lun, DWORD length, unsigned char *buffer)
 {
 	int rv;
 	int reader = LunToReaderIndex(lun);
-#ifdef DEBUG_LEVEL_COMM
 	char debug_header[] = "-> 121234 ";
 
 	sprintf(debug_header, "-> %06X ", (int)lun);
-#endif
 
-#ifdef DEBUG_LEVEL_COMM
 	DEBUG_XXD(debug_header, buffer, length);
-#endif
 
-	rv = usb_bulk_write(usbDevice[reader].handle, usbDevice[reader].dev->config->interface->altsetting->endpoint[USB_OUTEP].bEndpointAddress, buffer, length, USB_WRITE_TIMEOUT);
+	rv = usb_bulk_write(usbDevice[reader].handle, usbDevice[reader].bulk_out, buffer, length, USB_WRITE_TIMEOUT);
 
 	if (rv < 0)
 	{
-		DEBUG_CRITICAL4("%s/%s: %s", usbDevice[reader].dev->bus->dirname,
-			usbDevice[reader].dev->filename, strerror(errno));
-
-		/* reset in case of timeout (usually means a reader freeze)
-		 * The application will receive an error but can try to reconnect.
-		 * Without the patch the reader must be physically unpluged-repluged */
-		if (errno == ETIMEDOUT)
+		DEBUG_CRITICAL("POUET");
+		if (usbDevice[reader].dev->bus)
 		{
-			DEBUG_CRITICAL3("Reseting the reader: %s/%s",
-				usbDevice[reader].dev->bus->dirname,
-				usbDevice[reader].dev->filename);
-			usb_reset(usbDevice[reader].handle);
+			DEBUG_CRITICAL4("%s/%s: %s", usbDevice[reader].dev->bus->dirname,
+				usbDevice[reader].dev->filename, strerror(errno));
+
+			/* reset in case of timeout (usually means a reader freeze)
+			 * The application will receive an error but can try to reconnect.
+			 * Without the patch the reader must be physically
+			 * unpluged-repluged */
+			if (errno == ETIMEDOUT)
+			{
+				DEBUG_CRITICAL3("Reseting the reader: %s/%s",
+					usbDevice[reader].dev->bus->dirname,
+					usbDevice[reader].dev->filename);
+				usb_reset(usbDevice[reader].handle);
+			}
 		}
+		else
+			DEBUG_CRITICAL2("usb_bulk_write(no device): %s", strerror(errno));
+
 		return STATUS_UNSUCCESSFUL;
 	}
 
@@ -270,14 +286,12 @@ status_t ReadUSB(DWORD lun, DWORD * length, unsigned char *buffer)
 {
 	int rv;
 	int reader = LunToReaderIndex(lun);
-#ifdef DEBUG_LEVEL_COMM
 	char debug_header[] = "<- 121234 ";
 
 	sprintf(debug_header, "<- %06X ", (int)lun);
-#endif
 
 
-	rv = usb_bulk_read(usbDevice[reader].handle, usbDevice[reader].dev->config->interface->altsetting->endpoint[USB_INEP].bEndpointAddress, buffer, *length, USB_READ_TIMEOUT);
+	rv = usb_bulk_read(usbDevice[reader].handle, usbDevice[reader].bulk_in, buffer, *length, USB_READ_TIMEOUT);
 	*length = rv;
 
 	if (rv < 0)
@@ -287,9 +301,7 @@ status_t ReadUSB(DWORD lun, DWORD * length, unsigned char *buffer)
 		return STATUS_UNSUCCESSFUL;
 	}
 
-#ifdef DEBUG_LEVEL_COMM
 	DEBUG_XXD(debug_header, buffer, *length);
-#endif
 
 	return STATUS_SUCCESS;
 } /* ReadUSB */
@@ -307,7 +319,8 @@ status_t CloseUSB(DWORD lun)
 	DEBUG_COMM3("device: %s/%s", usbDevice[reader].dev->bus->dirname,
 		usbDevice[reader].dev->filename);
 
-	usb_release_interface(usbDevice[reader].handle, usbDevice[reader].dev->config->interface->altsetting->bInterfaceNumber);
+	usb_release_interface(usbDevice[reader].handle,
+		usbDevice[reader].interface);
 	usb_close(usbDevice[reader].handle);
 
 	/* mark the resource unused */
