@@ -1,5 +1,5 @@
 /*
- * $Id: GCdebug.c,v 1.6 2003/03/21 22:34:08 rousseau Exp $
+ * $Id: GCdebug.c,v 1.7 2005/06/17 10:20:43 rousseau Exp $
  * GCdebug.c: log (or not) messages
  * Copyright (C) 2001 Ludovic Rousseau <ludovic.rousseau@free.fr>
  * 
@@ -11,8 +11,6 @@
 #include "Config.h"
 #include "GCdebug.h"
 
-#ifdef DEBUG
-
 #include <stdarg.h>
 #include <stdio.h>
 #include <string.h>
@@ -21,7 +19,7 @@
 
 static char DebugBuffer[DEBUG_BUF_SIZE];
 
-void debug_msg(char *fmt, ...)
+void log_msg(const int priority, const char *fmt, ...)
 {
 	va_list argptr;
 
@@ -32,7 +30,8 @@ void debug_msg(char *fmt, ...)
 	fprintf(stderr, "%s\n", DebugBuffer);
 } /* debug_msg */
 
-void debug_xxd(const char *msg, const unsigned char *buffer, const int len)
+void log_xxd(const int priority, const char *msg, const unsigned char *buffer,
+	const int len)
 {
 	int i;
 	unsigned char *c, *debug_buf_end;
@@ -51,5 +50,3 @@ void debug_xxd(const char *msg, const unsigned char *buffer, const int len)
 	fprintf(stderr, "%s\n", DebugBuffer);
 } /* debug_xxd */
 
-#endif
-
