@@ -1,6 +1,6 @@
 /*
  *  GemCore.h
- *  $Id: GemCore.h,v 1.13 2004/02/21 16:50:16 rousseau Exp $
+ *  $Id: GemCore.h,v 1.15 2004/07/03 21:42:48 rousseau Exp $
  *  ifd-GemPC
  *
  *  Created by JL Giraud <jl.giraud@free.fr> on Sun Nov 19 2000.
@@ -13,88 +13,90 @@
 #ifndef _GEMCORE_H_
 #define _GEMCORE_H_
 
-// Size of an ISO command (CLA+INS+P1+P2)
+#include <pcsclite.h>
+
+/* Size of an ISO command (CLA+INS+P1+P2) */
 #define ISO_CMD_SIZE 4
-//Offset of the length byte in an TPDU
+/* Offset of the length byte in an TPDU */
 #define ISO_OFFSET_LENGTH 4
-//Offset of the data in a TPDU
+/* Offset of the data in a TPDU */
 #define ISO_OFFSET_TPDU_DATA 5
-//ISO length size (1 in general)
+/* ISO length size (1 in general) */
 #define ISO_LENGTH_SIZE 1
-//ISO SW size
+/* ISO SW size */
 #define ISO_SIZE_SW 2
 
-// Communication buffer size (max=cmd+adpu+Lc+data+Le)
+/* Communication buffer size (max=cmd+adpu+Lc+data+Le) */
 #define CMD_BUF_SIZE (1+4+1+256+1)
-// Larger communication buffer size (max=reader status+data+sw)
+/* Larger communication buffer size (max=reader status+data+sw) */
 #define RESP_BUF_SIZE (1+256+2)
 
-// Size of the command field in a gemcore command
+/* Size of the command field in a gemcore command */
 #define GC_SIZE_CMD 1
-// Size of the reader status
+/* Size of the reader status */
 #define GC_SIZE_STATUS 1
 
-// *** should disapear
-// Offset of the status byte in a reader answer (CMD level)
+/* *** should disapear */
+/* Offset of the status byte in a reader answer (CMD level) */
 #define GC_STATUS_OFFSET 0
 
-// Offset of the command byte in a GemCore command (CMD level)
+/* Offset of the command byte in a GemCore command (CMD level) */
 #define GC_OFFSET_CMD 0
-// Offset of the APDU in a GemCore command (CMD level)
+/* Offset of the APDU in a GemCore command (CMD level) */
 #define GC_OFFSET_APDU 1
-// Offset of the Lc byte in the APDU of a Gemcore command
+/* Offset of the Lc byte in the APDU of a Gemcore command */
 #define GC_OFFSET_LENGTH (GC_OFFSET_APDU+ISO_OFFSET_LENGTH)
-//Offset of the Data in a TPDU Gemcore command
+/* Offset of the Data in a TPDU Gemcore command */
 #define GC_OFFSET_TPDU_CMD_DATA (GC_OFFSET_APDU+ISO_OFFSET_TPDU_DATA)
-// Offset of the DATA in a GemCore response (CMD level)
+/* Offset of the DATA in a GemCore response (CMD level) */
 #define GC_OFFSET_RESP_DATA 1
-// Nb of bytes added to the APDU in a GemCore command (CMD level)
+/* Nb of bytes added to the APDU in a GemCore command (CMD level) */
 #define GC_FORMAT_SIZE 1
 
-// STAT byte offset in a response to CARD STATUS command (CMD level)
+/* STAT byte offset in a response to CARD STATUS command (CMD level) */
 #define GC_OFFSET_STAT_BYTE 0
-//Bit mask to get the reader power status
+/* Bit mask to get the reader power status */
 #define GC_MASK_POWER 0x02
-// Bit mask to detect ICC presence
+/* Bit mask to detect ICC presence */
 #define GC_MASK_ICC_PRESENCE 0x04
-// size if CARD STATUS response
+/* size if CARD STATUS response */
 #define GC_SIZE_CARD_STATUS 6
 
-//Maximum size of Data for ISO_Output before pcLongDataADPU is required
+/* Maximum size of Data for ISO_Output before pcLongDataADPU is required */
 #define GC_ISO_OUTPUT_MAX_DATA_LENGTH 252
 
-//Maximum size of Data for ISO_Output before pcLongDataADPU is required
+/* Maximum size of Data for ISO_Output before pcLongDataADPU is required */
 #define GC_ISO_INPUT_MAX_DATA_LENGTH 248
 
-//Maximum length for APDU command (ie CMD+2xlength+DataIn)
+/* Maximum length for APDU command (ie CMD+2xlength+DataIn) */
 #define GC_ISO_EXC_CMD_MAX_APDU_LENGTH 254
 
-//Maximum length for APDU response (ie Data + SW)
+/* Maximum length for APDU response (ie Data + SW) */
 #define GC_ISO_EXC_RESP_MAX_APDU_LENGTH 254
 
-//Length of the reader response to a transmit command
+/* Length of the reader response to a transmit command */
 #define GC_READER_TRANSMIT_RESP_LENGTH 1
 
 
-//Powerflag (used to detect quick insertion removals unnoticed by the 
-//resource manager)
-//Initial value
+/* Powerflag (used to detect quick insertion removals unnoticed by the
+ * resource manager) */
+/* Initial value */
 #define POWERFLAGS_RAZ 0x00
-//Flag set when a power up has been requested
+/* Flag set when a power up has been requested */
 #define MASK_POWERFLAGS_PUP 0x01
-//Flag set when a power down is requested
+/* Flag set when a power down is requested */
 #define MASK_POWERFLAGS_PDWN 0x02
-// Flag set when reader and card are EMV (use only APDU exchange)
+/* Flag set when reader and card are EMV (use only APDU exchange) */
 #define MASK_POWERFLAGS_EMV 0x04
 
-// Size of the GemCore version string
+/* Size of the GemCore version string */
 #define IFD_LEN_VERSION 0x10
 
-// mode GemCore + ROS - TLP
+/* mode GemCore + ROS - TLP */
 #define IFD_MODE_ROSNOTLP 1
 
 
-// Gemcore error codes
+/* Gemcore error codes */
 typedef enum {
     GCORE_OK               = 0x00,
     GCORE_UNKNOWN_CMD      = 0x01,
@@ -120,7 +122,7 @@ typedef enum {
     GCORE_CARD_MISSING     = 0xFB
 } gcore_t;
 
-// Protocols 
+/* Protocols  */
 enum 
 {
     T_0                    = 0,
